@@ -310,7 +310,7 @@ Template::Preprocessor::TTML::CmdLineProc - Process command line arguments
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -397,7 +397,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Template-Preprocessor-TTML>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Template-Preprocessor-TTML>
 
 =item *
 
@@ -429,7 +429,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Template-Preprocessor-TTML>
+L<http://cpants.cpanauthors.org/dist/Template-Preprocessor-TTML>
 
 =item *
 
@@ -460,7 +460,7 @@ L<http://deps.cpantesters.org/?module=Template::Preprocessor::TTML>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-template-preprocessor-ttml at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Template-Preprocessor-TTML>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Template-Preprocessor-TTML>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
